==> devextreme-21.2.14-build-23115-0306.tgz: package/cjs/ui/scheduler/appointments/rendering_strategies/strategy_week.js <==
/**
 * DevExtreme (cjs/ui/scheduler/appointments/rendering_strategies/strategy_week.js)
 * Version: 21.2.13 (build 23115-0306)
 * Build date: Tue Apr 25 2023
 *
 * Copyright (c) 2012 - 2023 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
exports.default = void 0;
var _strategy_vertical = _interopRequireDefault(require("./strategy_vertical"));

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    }
}

function _inheritsLoose(subClass, superClass) {
    subClass.prototype = Object.create(superClass.prototype);
    subClass.prototype.constructor = subClass;
    _setPrototypeOf(subClass, superClass)
}

function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function(o, p) {
        o.__proto__ = p;
        return o
    };
    return _setPrototypeOf(o, p)
}
var WeekAppointmentRenderingStrategy = function(_VerticalRenderingStr) {
    _inheritsLoose(WeekAppointmentRenderingStrategy, _VerticalRenderingStr);

    function WeekAppointmentRenderingStrategy() {
        return _VerticalRenderingStr.apply(this, arguments) || this
    }
    var _proto = WeekAppointmentRenderingStrategy.prototype;
    _proto.isApplyCompactAppointmentOffset = function() {
        if (this.isAdaptive && 0 === this._getMaxAppointmentCountPerCellByType()) {
            return false
        }
        return this.supportCompactDropDownAppointments()
    };
    return WeekAppointmentRenderingStrategy
}(_strategy_vertical.default);
var _default = WeekAppointmentRenderingStrategy;
exports.default = _default;
module.exports = exports.default;
module.exports.default = exports.default;

==> devextreme-22.1.5-build-22237-0310.tgz: package/cjs/ui/scheduler/appointments/rendering_strategies/strategy_week.js <==
/**
 * DevExtreme (cjs/ui/scheduler/appointments/rendering_strategies/strategy_week.js)
 * Version: 22.1.4 (build 22237-0310)
 * Build date: Thu Aug 25 2022
 *
 * Copyright (c) 2012 - 2022 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
exports.default = void 0;
var _strategy_vertical = _interopRequireDefault(require("./strategy_vertical"));

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    }
}

function _inheritsLoose(subClass, superClass) {
    subClass.prototype = Object.create(superClass.prototype);
    subClass.prototype.constructor = subClass;
    _setPrototypeOf(subClass, superClass)
}

function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function(o, p) {
        o.__proto__ = p;
        return o
    };
    return _setPrototypeOf(o, p)
}
var WeekAppointmentRenderingStrategy = function(_VerticalRenderingStr) {
    _inheritsLoose(WeekAppointmentRenderingStrategy, _VerticalRenderingStr);

    function WeekAppointmentRenderingStrategy() {
        return _VerticalRenderingStr.apply(this, arguments) || this
    }
    var _proto = WeekAppointmentRenderingStrategy.prototype;
    _proto.isApplyCompactAppointmentOffset = function() {
        if (this.isAdaptive && 0 === this._getMaxAppointmentCountPerCellByType()) {
            return false
        }
        return this.supportCompactDropDownAppointments()
    };
    return WeekAppointmentRenderingStrategy
}(_strategy_vertical.default);
var _default = WeekAppointmentRenderingStrategy;
exports.default = _default;
module.exports = exports.default;
module.exports.default = exports.default;
